@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.203 2004/07/13 20:23:31 bmeyer Exp $
+    $Id$
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
     */
 
@@ -34,7 +34,6 @@
 #include <kaction.h>
 #include <kapplication.h>
 #include <kcmdlineargs.h>
-#include <kcolorbutton.h>
 #include <kconfigdialog.h>
 #include <kcursor.h>
 #include <keditcl.h>
@@ -44,7 +43,6 @@
 #include <kmessagebox.h>
 #include <kprinter.h>
 #include <ksavefile.h>
-#include <kstdguiitem.h>
 #include <kstatusbar.h>
 #include <kspell.h>
 #include <kurldrag.h>
@@ -78,8 +76,6 @@ TopLevel::TopLevel (QWidget *, const char *name)
 
   connect(kapp,SIGNAL(kdisplayPaletteChanged()),this,SLOT(set_colors()));
 
-  resize(550,400); // Default size
-
   setupStatusBar();
   setupActions();
 
@@ -87,7 +83,10 @@ TopLevel::TopLevel (QWidget *, const char *name)
 
   setupEditWidget();
 
-  setupGUI();
+  if (!initialGeometrySet())
+    resize( QSize(550, 400).expandedTo(minimumSizeHint()));
+  setupGUI(ToolBar | Keys | StatusBar | Create);
+  setAutoSaveSettings();
 
   setAcceptDrops(true);
 
@@ -107,7 +106,6 @@ void TopLevel::setupEditWidget()
   {
     eframe = new KEdit (this, "eframe");
     eframe->setOverwriteEnabled(true);
-    KCursor::setAutoHideCursor( eframe, true );
 
     connect(eframe, SIGNAL(CursorPositionChanged()),this,
            SLOT(statusbar_slot()));
@@ -441,21 +439,36 @@ void TopLevel::spell_done(const QString& newtext)
   kspell->cleanUp();
 }
 
+// Replace ISpell with the name of the actual spell checker.
+// TODO: Use %1 in the original string instead when string freeze is over.
+QString TopLevel::replaceISpell(QString msg, int client)
+{
+  switch(client)
+  {
+    case KS_CLIENT_ISPELL: msg.replace("ISpell", "<b>ispell</b>"); break;
+    case KS_CLIENT_ASPELL: msg.replace("ISpell", "<b>aspell</b>"); break;
+    case KS_CLIENT_HSPELL: msg.replace("ISpell", "<b>hspell</b>"); break;
+  }
+  msg.replace("\n", "<p>");
+  return "<qt>"+msg+"</qt>";
+}
+
 void TopLevel::spell_finished( )
 {
   KSpell::spellStatus status = kspell->status();
+  int client = kspellconfigOptions->client();
   delete kspell;
   kspell = 0;
   if (status == KSpell::Error)
   {
-     KMessageBox::sorry(this, i18n("ISpell could not be started.\n"
-     "Please make sure you have ISpell properly configured and in your PATH."));
+     KMessageBox::sorry(this, replaceISpell(i18n("ISpell could not be started.\n"
+     "Please make sure you have ISpell properly configured and in your PATH."), client));
   }
   else if (status == KSpell::Crashed)
   {
      eframe->spellcheck_stop();
      statusBar()->changeItem (i18n("Spellcheck:  Crashed."), ID_GENERAL);
-     KMessageBox::sorry(this, i18n("ISpell seems to have crashed."));
+     KMessageBox::sorry(this, replaceISpell(i18n("ISpell seems to have crashed."), client));
   }
 }
 
@@ -605,11 +618,11 @@ bool TopLevel::queryClose()
                     msg = i18n(""
 	                "Could not save the file.\n"
 	                "Exit anyways?");
-                    switch( KMessageBox::warningYesNo( this, msg ) )
+                    switch( KMessageBox::warningContinueCancel( this, msg, QString::null, KStdGuiItem::quit() ) )
                     {
-                     case KMessageBox::Yes:
+                     case KMessageBox::Continue:
                               return true; // Exit.
-                     case KMessageBox::No:
+                     case KMessageBox::Cancel:
                      default:
                               return false; // Don't exit.
                     }
@@ -936,7 +949,7 @@ void TopLevel::print()
            int y = dy*2;
            while(lineCount < maxLineCount) {
               QString text = eframe->textLine(lineCount);
-              if( text == "" )
+              if( text.isEmpty() )
                 text = " ";	// don't ignore empty lines
               QRect r = p->boundingRect(0, y, body.width(), body.height(),
 			QPainter::ExpandTabs | QPainter::WordBreak, text);
@@ -1126,7 +1139,7 @@ void TopLevel::openURL( const KURL& _url, int _mode )
     }
     else
     {
-      if (_mode & OPEN_NEW == 0)
+      if ((_mode & OPEN_NEW) == 0)
       {
          KMessageBox::error(this, i18n("Cannot download file."));
          return;
@@ -1246,7 +1259,7 @@ static const KCmdLineOptions options[] =
 	KCmdLineLastOption
 };
 
-extern "C" int kdemain (int argc, char **argv)
+extern "C" KDE_EXPORT int kdemain (int argc, char **argv)
 {
 	bool have_top_window = false;
 
