@@ -3,6 +3,7 @@
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  * Copyright (c) 2002 Marc Mutz <mutz@kde.org>
+ * Copyright (c) 2006 Flavio Castelli <flavio.castelli@gmail.com>
  *
  * Requires the Qt widget libraries, available at no cost at
  * http://www.troll.no/
@@ -19,7 +20,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 // my headers:
@@ -72,7 +73,14 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
     top_layout->addWidget( runMonitor );
     QToolTip::add( runMonitor, i18n( "This box enables the battery state icon in the panel" ) );
     connect( runMonitor, SIGNAL(clicked()), this, SLOT(configChanged()) );
+    connect( runMonitor, SIGNAL(clicked()), this, SLOT(runMonitorChanged()) );
 
+    // show also the battery level percentage
+    showLevel = new QCheckBox( i18n("Show battery level percentage"), this );
+    top_layout->addWidget( showLevel );
+    QToolTip::add( showLevel, i18n( "This box enables a text message near the battery state icon containing battery level percentage" ) );
+    connect( showLevel, SIGNAL(clicked()), this, SLOT(configChanged()) );
+    
     notifyMe = new QCheckBox( i18n("&Notify me whenever my battery becomes fully charged"), this );
     top_layout->addWidget( notifyMe );
     QToolTip::add( notifyMe, i18n( "This box enables a dialog box that pops up when your battery becomes fully charged" ) );
@@ -186,6 +194,7 @@ BatteryConfig::~BatteryConfig()
 void BatteryConfig::save()
 {
         enablemonitor = runMonitor->isChecked();
+        showlevel = showLevel->isChecked();
         useblanksaver = blankSaver->isChecked();
         notifyme = notifyMe->isChecked();
 
@@ -198,6 +207,7 @@ void BatteryConfig::save()
         config->setGroup("BatteryDefault");
 
         config->writeEntry("Enable", enablemonitor);
+        config->writeEntry("ShowLevel", showlevel);
         config->writeEntry("NotifyMe", notifyme);
         config->writeEntry("BlankSaver", useblanksaver);
         config->writeEntry("Poll", poll_time);
@@ -211,10 +221,17 @@ void BatteryConfig::save()
 
 void BatteryConfig::load()
 {
-       	config->setGroup("BatteryDefault");
+	load( false );
+}
+
+void BatteryConfig::load(bool useDefaults)
+{
+        config->setReadDefaults( useDefaults );
+        config->setGroup("BatteryDefault");
 
         poll_time = config->readNumEntry("Poll", 20);
         enablemonitor = config->readBoolEntry("Enable", true);
+        showlevel = config->readBoolEntry("ShowLevel", false);
         notifyme = config->readBoolEntry("NotifyMe", false);
         useblanksaver = config->readBoolEntry("BlankSaver", false);
 
@@ -223,6 +240,7 @@ void BatteryConfig::load()
         chargebattery = config->readEntry("ChargePixmap", "laptop_charge");
 
         runMonitor->setChecked(enablemonitor);
+        showLevel->setChecked(showlevel);
 	blankSaver->setChecked(useblanksaver);
 	notifyMe->setChecked(notifyme);
         if (apm) {
@@ -233,36 +251,19 @@ void BatteryConfig::load()
         }
         battery_pm = SmallIcon(nochargebattery, 20, KIcon::DefaultState, instance);
         battery_nopm = SmallIcon(nobattery, 20, KIcon::DefaultState, instance);
-        changed(false);
+        emit changed(useDefaults);
 	BatteryStateUpdate();
 }
 
 void BatteryConfig::defaults()
 {
-        poll_time = 20;
-        enablemonitor = true;
-	useblanksaver = false;
-	notifyme = false;
-
-        nobattery = "laptop_nobattery";
-        nochargebattery = "laptop_nocharge";
-        chargebattery = "laptop_charge";
-
-        runMonitor->setChecked(enablemonitor);
-        notifyMe->setChecked(notifyme);
-	blankSaver->setChecked(useblanksaver);
-        if (apm) {
-                editPoll->setValue(poll_time);
-                buttonNoCharge->setIcon(nochargebattery);
-                buttonCharge->setIcon(chargebattery);
-                buttonNoBattery->setIcon(nobattery);
-        }
-        battery_pm = SmallIcon(nochargebattery, 20, KIcon::DefaultState, instance);
-        battery_nopm = SmallIcon(nobattery, 20, KIcon::DefaultState, instance);
-        changed(true);
-	BatteryStateUpdate();
+	load( true );
 }
 
+void BatteryConfig::runMonitorChanged()
+{
+    showLevel->setEnabled (runMonitor->isChecked());
+}
 
 void BatteryConfig::configChanged()
 {
