@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "power.h"
@@ -382,6 +382,13 @@ void PowerConfig::save()
 
 void PowerConfig::load()
 {
+	load( false );
+}
+
+void PowerConfig::load(bool useDefaults)
+{
+  config->setReadDefaults( useDefaults );
+
   config->setGroup("LaptopPower");
   nopower = config->readNumEntry("NoPowerSuspend", (nopowerStandby?1:nopowerSuspend?2:0));
   power = config->readNumEntry("PowerSuspend", 0);
@@ -482,85 +489,12 @@ void PowerConfig::load()
 		powerValThrottle->setEnabled(power_throttle_enabled);
 	}
   }
-  changed(false);
+  emit changed( useDefaults );
 }
 
 void PowerConfig::defaults()
 {
-  setPower(1, 0);
-  edit_wait = 20;
-  noedit_wait = 5;
-  nopower_bright_enabled = 0;
-  power_bright_enabled = 0;
-  nopower_bright_val = 0;
-  power_bright_val = 0;
-  nopower_performance_enabled = 0;
-  power_performance_enabled = 0;
-  nopower_performance_val = "";
-  power_performance_val = "";
-  nopower_throttle_enabled = 0;
-  power_throttle_enabled = 0;
-  nopower_throttle_val = "";
-  power_throttle_val = "";
-  lav_enabled = 0;
-  nolav_enabled = 0;
-  edit_lav = -1;
-  noedit_lav = -1;
-  if (editwait) {
-	editwait->setValue(edit_wait);
-        noeditwait->setValue(noedit_wait);
-	if (editlav) {
-		editlav->setValue(edit_lav);
-		editlav->setEnabled(lav_enabled);
-	}
-	if (noeditlav) {
-		noeditlav->setValue(noedit_lav);
-		noeditlav->setEnabled(nolav_enabled);
-	}
-	if (enablelav)
-		enablelav->setChecked(lav_enabled);
-	if (noenablelav)
-		noenablelav->setChecked(nolav_enabled);
-	if (nopowerBrightness) 
-		nopowerBrightness->setChecked(nopower_bright_enabled);
-	if (powerBrightness) 
-		powerBrightness->setChecked(power_bright_enabled);
-	if (nopowerValBrightness) {
-		nopowerValBrightness->setValue(nopower_bright_val);
-		nopowerValBrightness->setEnabled(nopower_bright_enabled);
-	}
-	if (powerValBrightness) {
-		powerValBrightness->setValue(power_bright_val);
-		powerValBrightness->setEnabled(power_bright_enabled);
-	}
-
-
-	if (nopowerPerformance) 
-		nopowerPerformance->setChecked(nopower_performance_enabled);
-	if (powerPerformance) 
-		powerPerformance->setChecked(power_performance_enabled);
-	if (nopowerValPerformance) {
-		nopowerValPerformance->setCurrentItem(0);
-		nopowerValPerformance->setEnabled(nopower_performance_enabled);
-	}
-	if (powerValPerformance) {
-		powerValPerformance->setCurrentItem(0);
-		powerValPerformance->setEnabled(power_performance_enabled);
-	}
-	if (nopowerThrottle) 
-		nopowerThrottle->setChecked(nopower_throttle_enabled);
-	if (powerThrottle) 
-		powerThrottle->setChecked(power_throttle_enabled);
-	if (nopowerValThrottle) {
-		nopowerValThrottle->setCurrentItem(0);
-		nopowerValThrottle->setEnabled(nopower_throttle_enabled);
-	}
-	if (powerValThrottle) {
-		powerValThrottle->setCurrentItem(0);
-		powerValThrottle->setEnabled(power_throttle_enabled);
-	}
-  }
-  changed(true);
+	load( true );
 }
 
 int  PowerConfig::getNoPower()
