@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <qtimer.h>
@@ -105,9 +105,9 @@ KTimerPref::KTimerPref( QWidget *parent, const char *name )
     d->jobs.setAutoDelete( true );
 
     // set icons
-    m_stop->setPixmap( SmallIcon("player_stop") );
-    m_pause->setPixmap( SmallIcon("player_pause") );
-    m_start->setPixmap( SmallIcon("1rightarrow") );
+    m_stop->setIconSet( SmallIconSet("player_stop") );
+    m_pause->setIconSet( SmallIconSet("player_pause") );
+    m_start->setIconSet( SmallIconSet("1rightarrow") );
 
     // create tray icon
     KSystemTray *tray = new KSystemTray( this, "TimerTray" );
