@@ -17,6 +17,14 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with SuperKaramba; if not, write to the Free Software
-*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 ****************************************************************************/
 
+class KarambaSessionManaged : public KSessionManaged
+{
+public:
+    KarambaSessionManaged() {};
+
+    virtual bool commitData( QSessionManager& );
+    virtual bool saveState( QSessionManager& );
+};
